#!/bin/sh

# sbopkglint test, must be sourced by sbopkglint (not run standalone).

# PKG, PRGNAM, VERSION, ARCH are set by sbopkglint. also the current
# directory is the root of the installed package tree.

#######################################################################
# check for badly-built python packages that end up named UNKNOWN.
# at some point there will probably be more python checks added here.

find usr/lib*/python* -type d -a -name 'UNKNOWN*' 2>/dev/null > .badpython.$$
if [ -s .badpython.$$ ]; then
	warn "invalid/broken Python module(s): $(cat .badpython.$$)"
fi
rm -f .badpython.$$
