#!/bin/sh

# We have hardcoded version strings in the various scripts, this will
# update them all. Don't run directly, use "make version".

VERSION="$1"
if [ -z "$VERSION" ]; then
	echo "$0: missing VERSION argument" 1>&2
	exit 1
fi

sed -i "s,^VER=.*,VER=$VERSION," sbopkglint
sed -i "/^\$VERSION=/s,=.*,=\"$VERSION\";," sbolint sbofixinfo
sed -i "s,^VERSION=.*,VERSION=$VERSION," sbodl
