#!/bin/sh

# sbopkglint test, must be sourced by sbopkglint (not run standalone).

# PKG, PRGNAM, VERSION, ARCH are set by sbopkglint. also the current
# directory is the root of the installed package tree.

#######################################################################
# the SBo perl template has this line:
# find $PKG -name perllocal.pod -o -name ".packlist" -o -name "*.bs" | xargs rm -f || true
# this just checks that the files that are supposed to be removed,
# really are removed.

find_warnfiles "forbidden files:" \
	-name perllocal.pod -o -name ".packlist" -o -name "*.bs"
